/*
 * Copyright 2016-present Open Networking Laboratory
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.onosproject.nemo.model.object.node.definitions;

import static com.google.common.base.MoreObjects.toStringHelper;

import java.util.Objects;

import org.onosproject.nemo.model.common.NodeType;

/**
 * The key to differentiate node definition.
 */
public class NodeDefinitionKey {
    private final NodeType nodeType;

    /**
     * Creates a node definition key from a given node type.
     *
     * @param nodeType the node type
     */
    public NodeDefinitionKey(NodeType nodeType) {
        this.nodeType = nodeType;
    }

    /**
     * Creates a copy from a given node definition key instance.
     *
     * @param key the node definition key
     */
    public NodeDefinitionKey(NodeDefinitionKey key) {
        nodeType = key.nodeType;
    }

    /**
     * Returns the node type of this instance.
     *
     * @return node type
     */
    public NodeType getNodeType() {
        return nodeType;
    }

    @Override
    public int hashCode() {
        return nodeType.hashCode();
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        NodeDefinitionKey other = (NodeDefinitionKey) obj;
        return Objects.equals(nodeType, other.nodeType);
    }

    @Override
    public String toString() {
        return toStringHelper(this).add("nodeType", nodeType).toString();
    }
}