/*
 * Copyright 2016-present Open Networking Laboratory
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.onosproject.nemo.model.object.node.instance;

import org.onosproject.nemo.model.common.PropertyName;

import java.util.Objects;

import static com.google.common.base.MoreObjects.toStringHelper;

/**
 * The key to differentiate user roles.
 */
public class PropertyKey {
    private final PropertyName propertyName;

    /**
     * Creates a property key from a given property name.
     *
     * @param name the property name
     */
    public PropertyKey(PropertyName name) {
        propertyName = name;
    }

    /**
     * Creates a copy from a given property key instance.
     *
     * @param key the property key
     */
    public PropertyKey(PropertyKey key) {
        propertyName = key.propertyName;
    }

    /**
     * Returns the property name of this instance.
     *
     * @return property name
     */
    public PropertyName getPropertyName() {
        return propertyName;
    }

    @Override
    public int hashCode() {
        return propertyName.hashCode();
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        PropertyKey other = (PropertyKey) obj;
        return Objects.equals(propertyName, other.propertyName);
    }

    @Override
    public String toString() {
        return toStringHelper(this).add("propertyName", propertyName)
                .toString();
    }
}