/*
 * Copyright 2016-present Open Networking Laboratory
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.onosproject.nemo.model.object.property.instance.property.values;

import java.util.Objects;

import static com.google.common.base.MoreObjects.toStringHelper;

/**
 * The key to differentiate string value.
 */
public class StringValueKey {
    private final String value;
    private final long order;

    /**
     * Creates a string value key from a given value.
     *
     * @param order the string value key order
     * @param value the string value
     */
    public StringValueKey(long order, String value) {
        this.order = order;
        this.value = value;
    }

    /**
     * Creates a copy from a given string value key instance.
     *
     * @param source the string value key
     */
    public StringValueKey(StringValueKey source) {
        value = source.value;
        order = source.order;
    }

    /**
     * Returns the value of this instance.
     *
     * @return string value
     */
    public String getValue() {
        return value;
    }

    /**
     * Returns the order of this instance.
     *
     * @return order the order
     */
    public long getOrder() {
        return order;
    }

    @Override
    public int hashCode() {
        return Objects.hash(value, order);
    }

    @Override
    public boolean equals(Object obj) {
        if (this == obj) {
            return true;
        }
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        StringValueKey o = (StringValueKey) obj;
        return Objects.equals(value, o.value) &&
                Objects.equals(order, o.order);
    }

    @Override
    public String toString() {
        return toStringHelper(this).add("value", value)
                .add("order", order)
                .toString();
    }
}