/*
 * Copyright 2016-present Open Networking Laboratory
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.onosproject.nemo.model.operation.action.instance.parameter.values;

/**
 * Utilities for the action parameter values package.
 */
public final class Utils {

    private static final long MIN_VALUE = 0L;
    private static final long MAX_VALUE = 4294967295L;
    private static final String E_OUT_OF_RANGE =
              "Invalid range: %s, expected: [[" + MIN_VALUE +
              ".." + MAX_VALUE + "]]";

    /**
     * Checks if the value is in range.
     *
     * @param value value to be checked
     * @throws IllegalArgumentException if the value is out of range
     */
    public static void checkOrderRange(long value) {
        if (value < MIN_VALUE || value > MAX_VALUE) {
            throw new IllegalArgumentException(
                    String.format(E_OUT_OF_RANGE, value));
        }
    }
}