package org.onosproject.nemo.model.object.node.definitions;

import static junit.framework.Assert.assertEquals;

import org.junit.Test;
import org.onosproject.nemo.model.common.NodeType;
import com.google.common.testing.EqualsTester;

/**
 * Unit tests for {@link NodeDefinitionBuilder}.
 */
public class NodeDefinitionBuilderTest {

    private static final String TYPE = "SomeName";
    private static final String OTHER_TYPE = "OtherName";
    private static final String TYPE_ERROR_MSG = "name not set";
    private static final String KEY_ERROR_MSG = "key not set";
    private NodeDefinitionKey key;
    private NodeType name;
    private NodeType otherName;
    private NodeDefinition listParam;
    private NodeDefinition def;
    private NodeDefinition copy;
    private NodeDefinition diff;

    @Test
    public void buildNodeDefinitionWithNodeDefinitionKey() {
        name = new NodeType(TYPE);
        key = new NodeDefinitionKey(name);
        listParam = new NodeDefinitionBuilder()
                .key(key)
                .build();
        def = new NodeDefinitionBuilder()
                .key(key)
                .addAugmentation(NodeDefinition.class, listParam)
                .build();
        def = new NodeDefinitionBuilder(def)
                .addAugmentation(NodeDefinition.class, null)
                .build();
        assertEquals(TYPE_ERROR_MSG, name, def.getNodeType());
        assertEquals(KEY_ERROR_MSG, key, def.getKey());
    }

    @Test
    public void buildNodeDefinitionWithNodeType() {
        name = new NodeType(TYPE);
        key = new NodeDefinitionKey(name);
        listParam = new NodeDefinitionBuilder()
                .nodeType(name)
                .build();
        def = new NodeDefinitionBuilder()
                .nodeType(name)
                .addAugmentation(NodeDefinition.class, listParam)
                .build();
        def = new NodeDefinitionBuilder(def)
                .addAugmentation(NodeDefinition.class, null)
                .build();
        assertEquals(TYPE_ERROR_MSG, name, def.getNodeType());
        assertEquals(KEY_ERROR_MSG, key, def.getKey());
    }

    @Test
    public void fromNodeWithNodeKey() {
        name = new NodeType(TYPE);
        key = new NodeDefinitionKey(name);
        def = new NodeDefinitionBuilder()
                .key(key)
                .build();
        copy = new NodeDefinitionBuilder(def).build();
        assertEquals(TYPE_ERROR_MSG, name, copy.getNodeType());
        assertEquals(KEY_ERROR_MSG, key, copy.getKey());
    }

    @Test
    public void fromActionWithActionName() {
        name = new NodeType(TYPE);
        key = new NodeDefinitionKey(name);
        def = new NodeDefinitionBuilder()
                .nodeType(name)
                .build();
        copy = new NodeDefinitionBuilder(def).build();
        assertEquals(TYPE_ERROR_MSG, name, copy.getNodeType());
        assertEquals(KEY_ERROR_MSG, key, copy.getKey());
    }

    @Test
    public void equality() {
        name = new NodeType(TYPE);
        def = new NodeDefinitionBuilder()
                .nodeType(name)
                .build();
        copy = new NodeDefinitionBuilder()
                .nodeType(name)
                .build();
        otherName = new NodeType(OTHER_TYPE);
        diff = new NodeDefinitionBuilder()
                .nodeType(otherName)
                .build();
        new EqualsTester()
                .addEqualityGroup(def, copy)
                .addEqualityGroup(diff)
                .testEquals();
    }
}