package org.onosproject.nemo.model.object.property.definitions;

import static junit.framework.Assert.assertEquals;

import org.junit.Test;
import org.onosproject.nemo.model.common.PropertyName;
import org.onosproject.nemo.model.object.property.definitions.PropertyDefinition.PropertyValueType;

import com.google.common.testing.EqualsTester;

/**
 * Unit tests for {@link PropertyDefinitionBuilder}.
 */
public class PropertyDefinitionBuilderTest {

    private static final String NAME = "SomeName";
    private static final String OTHER_NAME = "OtherName";
    private static final String NAME_ERROR_MSG = "name not set";
    private static final String KEY_ERROR_MSG = "key not set";
    private static final String TYPE_ERROR_MSG = "type not set";

    private PropertyDefinitionKey key;
    private PropertyDefinition.PropertyValueType type;
    private PropertyName name;
    private PropertyName otherName;
    private PropertyDefinition listParam;
    private PropertyDefinition def;
    private PropertyDefinition copy;
    private PropertyDefinition diff;

    @Test
    public void buildPropertyDefinitionWithPropertyDefinitionKey() {
        name = new PropertyName(NAME);
        key = new PropertyDefinitionKey(name);
        type = PropertyValueType.forValue(0);
        listParam = new PropertyDefinitionBuilder()
                .key(key)
                .build();
        def = new PropertyDefinitionBuilder()
                .key(key)
                .propertyValueType(type)
                .addAugmentation(PropertyDefinition.class, listParam)
                .build();
        def = new PropertyDefinitionBuilder(def)
                .addAugmentation(PropertyDefinition.class, null)
                .build();
        assertEquals(NAME_ERROR_MSG, name, def.getPropertyName());
        assertEquals(KEY_ERROR_MSG, key, def.getKey());
        assertEquals(TYPE_ERROR_MSG, type, def.getPropertyValueType());
    }

    @Test
    public void buildPropertyDefinitionWithPropertyName() {
        name = new PropertyName(NAME);
        key = new PropertyDefinitionKey(name);
        type = PropertyValueType.forValue(0);
        listParam = new PropertyDefinitionBuilder()
                .propertyName(name)
                .build();
        def = new PropertyDefinitionBuilder()
                .propertyValueType(type)
                .propertyName(name)
                .addAugmentation(PropertyDefinition.class, listParam)
                .build();
        def = new PropertyDefinitionBuilder(def)
                .addAugmentation(PropertyDefinition.class, null)
                .build();
        assertEquals(NAME_ERROR_MSG, name, def.getPropertyName());
        assertEquals(KEY_ERROR_MSG, key, def.getKey());
        assertEquals(TYPE_ERROR_MSG, type, def.getPropertyValueType());
    }

    @Test
    public void fromPropertyWithPropertyKey() {
        name = new PropertyName(NAME);
        key = new PropertyDefinitionKey(name);
        type = PropertyValueType.forValue(0);
        def = new PropertyDefinitionBuilder()
                .propertyValueType(type)
                .key(key)
                .build();
        copy = new PropertyDefinitionBuilder(def).build();
        assertEquals(NAME_ERROR_MSG, name, copy.getPropertyName());
        assertEquals(KEY_ERROR_MSG, key, copy.getKey());
        assertEquals(TYPE_ERROR_MSG, type, def.getPropertyValueType());
    }

    @Test
    public void fromPropertyWithPropertyName() {
        name = new PropertyName(NAME);
        key = new PropertyDefinitionKey(name);
        type = PropertyValueType.forValue(0);
        def = new PropertyDefinitionBuilder()
                .propertyValueType(type)
                .propertyName(name)
                .build();
        copy = new PropertyDefinitionBuilder(def).build();
        assertEquals(NAME_ERROR_MSG, name, copy.getPropertyName());
        assertEquals(KEY_ERROR_MSG, key, copy.getKey());
        assertEquals(TYPE_ERROR_MSG, type, def.getPropertyValueType());
    }

    @Test
    public void equality() {
        name = new PropertyName(NAME);
        def = new PropertyDefinitionBuilder()
                .propertyName(name)
                .build();
        copy = new PropertyDefinitionBuilder()
                .propertyName(name)
                .build();
        otherName = new PropertyName(OTHER_NAME);
        diff = new PropertyDefinitionBuilder()
                .propertyName(otherName)
                .build();
        new EqualsTester()
                .addEqualityGroup(def, copy)
                .addEqualityGroup(diff)
                .testEquals();
    }
}